@@ -73,7 +73,7 @@ public class Activator extends HousekeepingActivator {
 
     public static final String ALIAS = "/servlet/mobileconfig";
 
-    private boolean registered;
+    private volatile boolean registered;
 
     /**
      * Initializes a new {@link Activator}.
@@ -137,8 +137,10 @@ public class Activator extends HousekeepingActivator {
         if (null == service) {
             return;
         }
+
         try {
             service.registerServlet(ALIAS, new MobileConfigServlet(), null, null);
+            registered = true;
         } catch (ServletException e) {
             LOG.error("", e);
         } catch (NamespaceException e) {
@@ -157,7 +159,11 @@ public class Activator extends HousekeepingActivator {
 
         HttpService service = getService(HttpService.class);
         if (null != service) {
-            service.unregister(ALIAS);
+            boolean registered = this.registered;
+            if (registered) {
+                service.unregister(ALIAS);
+                this.registered = false;
+            }
         }
     }
 
